# openrqm.api.ExportApi

## Load the API package
```dart
import 'package:openrqm/api.dart';
```

All URIs are relative to *https://virtserver.swaggerhub.com/OpenRQM/OpenRQM/1.0.0*

Method | HTTP request | Description
------------- | ------------- | -------------
[**exportMarkdown**](ExportApi.md#exportMarkdown) | **GET** /export/markdown | Export a document as Markdown
[**exportPdf**](ExportApi.md#exportPdf) | **GET** /export/pdf | Export a document as PDF
[**exportRaw**](ExportApi.md#exportRaw) | **GET** /export/openrqm | Export a document as OpenRQM Data for import
[**getMarkdownTemplates**](ExportApi.md#getMarkdownTemplates) | **GET** /export/markdown/templates | Get all Markdown templates
[**getPdfTemplates**](ExportApi.md#getPdfTemplates) | **GET** /export/pdf/templates | Get all PDF templates


# **exportMarkdown**
> MultipartFile exportMarkdown(documentId, templateId)

Export a document as Markdown

### Example 
```dart
import 'package:openrqm/api.dart';
// TODO Configure API key authorization: APIKeyHeader
//defaultApiClient.getAuthentication<ApiKeyAuth>('APIKeyHeader').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('APIKeyHeader').apiKeyPrefix = 'Bearer';

var api_instance = ExportApi();
var documentId = 789; // int | The document to export
var templateId = 789; // int | The template to use for the export

try { 
    var result = api_instance.exportMarkdown(documentId, templateId);
    print(result);
} catch (e) {
    print("Exception when calling ExportApi->exportMarkdown: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **documentId** | **int**| The document to export | [default to null]
 **templateId** | **int**| The template to use for the export | [default to null]

### Return type

[**MultipartFile**](File.md)

### Authorization

[APIKeyHeader](../README.md#APIKeyHeader)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/zip

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **exportPdf**
> MultipartFile exportPdf(documentId, templateId)

Export a document as PDF

### Example 
```dart
import 'package:openrqm/api.dart';
// TODO Configure API key authorization: APIKeyHeader
//defaultApiClient.getAuthentication<ApiKeyAuth>('APIKeyHeader').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('APIKeyHeader').apiKeyPrefix = 'Bearer';

var api_instance = ExportApi();
var documentId = 789; // int | The document to export
var templateId = 789; // int | The template to use for the export

try { 
    var result = api_instance.exportPdf(documentId, templateId);
    print(result);
} catch (e) {
    print("Exception when calling ExportApi->exportPdf: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **documentId** | **int**| The document to export | [default to null]
 **templateId** | **int**| The template to use for the export | [default to null]

### Return type

[**MultipartFile**](File.md)

### Authorization

[APIKeyHeader](../README.md#APIKeyHeader)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/pdf

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **exportRaw**
> MultipartFile exportRaw(documentId)

Export a document as OpenRQM Data for import

### Example 
```dart
import 'package:openrqm/api.dart';
// TODO Configure API key authorization: APIKeyHeader
//defaultApiClient.getAuthentication<ApiKeyAuth>('APIKeyHeader').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('APIKeyHeader').apiKeyPrefix = 'Bearer';

var api_instance = ExportApi();
var documentId = 789; // int | The document to export

try { 
    var result = api_instance.exportRaw(documentId);
    print(result);
} catch (e) {
    print("Exception when calling ExportApi->exportRaw: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **documentId** | **int**| The document to export | [default to null]

### Return type

[**MultipartFile**](File.md)

### Authorization

[APIKeyHeader](../README.md#APIKeyHeader)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/zip

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getMarkdownTemplates**
> List<RQMTemplate> getMarkdownTemplates()

Get all Markdown templates

### Example 
```dart
import 'package:openrqm/api.dart';
// TODO Configure API key authorization: APIKeyHeader
//defaultApiClient.getAuthentication<ApiKeyAuth>('APIKeyHeader').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('APIKeyHeader').apiKeyPrefix = 'Bearer';

var api_instance = ExportApi();

try { 
    var result = api_instance.getMarkdownTemplates();
    print(result);
} catch (e) {
    print("Exception when calling ExportApi->getMarkdownTemplates: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<RQMTemplate>**](RQMTemplate.md)

### Authorization

[APIKeyHeader](../README.md#APIKeyHeader)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getPdfTemplates**
> List<RQMTemplate> getPdfTemplates()

Get all PDF templates

### Example 
```dart
import 'package:openrqm/api.dart';
// TODO Configure API key authorization: APIKeyHeader
//defaultApiClient.getAuthentication<ApiKeyAuth>('APIKeyHeader').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('APIKeyHeader').apiKeyPrefix = 'Bearer';

var api_instance = ExportApi();

try { 
    var result = api_instance.getPdfTemplates();
    print(result);
} catch (e) {
    print("Exception when calling ExportApi->getPdfTemplates: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<RQMTemplate>**](RQMTemplate.md)

### Authorization

[APIKeyHeader](../README.md#APIKeyHeader)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

