part of openrqm.api;



class DocumentsApi {
  final ApiClient apiClient;

  DocumentsApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Delete a document with HTTP info returned
  ///
  /// 
  Future deleteDocumentWithHttpInfo(int documentId) async {
    Object postBody;

    // verify required params are set
    if(documentId == null) {
     throw ApiException(400, "Missing required param: documentId");
    }

    // create path and map variables
    String path = "/document".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "documentId", documentId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'DELETE',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Delete a document
  ///
  /// 
  Future deleteDocument(int documentId) async {
    Response response = await deleteDocumentWithHttpInfo(documentId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Get a document with HTTP info returned
  ///
  /// 
  Future<Response> getDocumentWithHttpInfo(int documentId) async {
    Object postBody;

    // verify required params are set
    if(documentId == null) {
     throw ApiException(400, "Missing required param: documentId");
    }

    // create path and map variables
    String path = "/document".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "documentId", documentId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get a document
  ///
  /// 
  Future<RQMDocument> getDocument(int documentId) async {
    Response response = await getDocumentWithHttpInfo(documentId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'RQMDocument') as RQMDocument;
    } else {
      return null;
    }
  }

  /// Get all documents with HTTP info returned
  ///
  /// 
  Future<Response> getDocumentsWithHttpInfo() async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    String path = "/documents".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get all documents
  ///
  /// 
  Future<List<RQMDocument>> getDocuments() async {
    Response response = await getDocumentsWithHttpInfo();
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<RQMDocument>') as List).map((item) => item as RQMDocument).toList();
    } else {
      return null;
    }
  }

  /// Get all links of a document with HTTP info returned
  ///
  /// 
  Future<Response> getLinksOfDocumentWithHttpInfo(int documentId) async {
    Object postBody;

    // verify required params are set
    if(documentId == null) {
     throw ApiException(400, "Missing required param: documentId");
    }

    // create path and map variables
    String path = "/document/links".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "documentId", documentId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get all links of a document
  ///
  /// 
  Future<List<RQMLink>> getLinksOfDocument(int documentId) async {
    Response response = await getLinksOfDocumentWithHttpInfo(documentId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<RQMLink>') as List).map((item) => item as RQMLink).toList();
    } else {
      return null;
    }
  }

  /// Update a document with HTTP info returned
  ///
  /// 
  Future patchDocumentWithHttpInfo(RQMDocument document) async {
    Object postBody = document;

    // verify required params are set
    if(document == null) {
     throw ApiException(400, "Missing required param: document");
    }

    // create path and map variables
    String path = "/document".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'PATCH',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Update a document
  ///
  /// 
  Future patchDocument(RQMDocument document) async {
    Response response = await patchDocumentWithHttpInfo(document);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Add a document with HTTP info returned
  ///
  /// 
  Future postDocumentWithHttpInfo(RQMDocument document) async {
    Object postBody = document;

    // verify required params are set
    if(document == null) {
     throw ApiException(400, "Missing required param: document");
    }

    // create path and map variables
    String path = "/document".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Add a document
  ///
  /// 
  Future postDocument(RQMDocument document) async {
    Response response = await postDocumentWithHttpInfo(document);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

}
