part of openrqm.api;



class ElementsApi {
  final ApiClient apiClient;

  ElementsApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Delete an element with HTTP info returned
  ///
  /// 
  Future deleteElementWithHttpInfo(int elementId) async {
    Object postBody;

    // verify required params are set
    if(elementId == null) {
     throw ApiException(400, "Missing required param: elementId");
    }

    // create path and map variables
    String path = "/element".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "elementId", elementId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'DELETE',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Delete an element
  ///
  /// 
  Future deleteElement(int elementId) async {
    Response response = await deleteElementWithHttpInfo(elementId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Get all element types with HTTP info returned
  ///
  /// 
  Future<Response> getElementTypesWithHttpInfo() async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    String path = "/elementTypes".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get all element types
  ///
  /// 
  Future<List<RQMElementType>> getElementTypes() async {
    Response response = await getElementTypesWithHttpInfo();
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<RQMElementType>') as List).map((item) => item as RQMElementType).toList();
    } else {
      return null;
    }
  }

  /// Get all elements with HTTP info returned
  ///
  /// 
  Future<Response> getElementsWithHttpInfo(int documentId) async {
    Object postBody;

    // verify required params are set
    if(documentId == null) {
     throw ApiException(400, "Missing required param: documentId");
    }

    // create path and map variables
    String path = "/elements".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "documentId", documentId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get all elements
  ///
  /// 
  Future<List<RQMElement>> getElements(int documentId) async {
    Response response = await getElementsWithHttpInfo(documentId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<RQMElement>') as List).map((item) => item as RQMElement).toList();
    } else {
      return null;
    }
  }

  /// Get all links of a given element with HTTP info returned
  ///
  /// 
  Future<Response> getIncomingLinksOfElementWithHttpInfo(int elementId) async {
    Object postBody;

    // verify required params are set
    if(elementId == null) {
     throw ApiException(400, "Missing required param: elementId");
    }

    // create path and map variables
    String path = "/element/inlinks".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "elementId", elementId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get all links of a given element
  ///
  /// 
  Future<List<RQMLink>> getIncomingLinksOfElement(int elementId) async {
    Response response = await getIncomingLinksOfElementWithHttpInfo(elementId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<RQMLink>') as List).map((item) => item as RQMLink).toList();
    } else {
      return null;
    }
  }

  /// Get all links of a given element with HTTP info returned
  ///
  /// 
  Future<Response> getOutgoingLinksOfElementWithHttpInfo(int elementId) async {
    Object postBody;

    // verify required params are set
    if(elementId == null) {
     throw ApiException(400, "Missing required param: elementId");
    }

    // create path and map variables
    String path = "/element/outlinks".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "elementId", elementId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get all links of a given element
  ///
  /// 
  Future<List<RQMLink>> getOutgoingLinksOfElement(int elementId) async {
    Response response = await getOutgoingLinksOfElementWithHttpInfo(elementId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<RQMLink>') as List).map((item) => item as RQMLink).toList();
    } else {
      return null;
    }
  }

  /// Update an element with HTTP info returned
  ///
  /// 
  Future patchElementWithHttpInfo(RQMElement element) async {
    Object postBody = element;

    // verify required params are set
    if(element == null) {
     throw ApiException(400, "Missing required param: element");
    }

    // create path and map variables
    String path = "/element".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'PATCH',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Update an element
  ///
  /// 
  Future patchElement(RQMElement element) async {
    Response response = await patchElementWithHttpInfo(element);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Add an element with HTTP info returned
  ///
  /// 
  Future postElementWithHttpInfo(String aboveRank, String belowRank, RQMElement element) async {
    Object postBody = element;

    // verify required params are set
    if(aboveRank == null) {
     throw ApiException(400, "Missing required param: aboveRank");
    }
    if(belowRank == null) {
     throw ApiException(400, "Missing required param: belowRank");
    }
    if(element == null) {
     throw ApiException(400, "Missing required param: element");
    }

    // create path and map variables
    String path = "/element".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "aboveRank", aboveRank));
      queryParams.addAll(_convertParametersForCollectionFormat("", "belowRank", belowRank));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Add an element
  ///
  /// 
  Future postElement(String aboveRank, String belowRank, RQMElement element) async {
    Response response = await postElementWithHttpInfo(aboveRank, belowRank, element);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

}
