part of openrqm.api;



class ExportApi {
  final ApiClient apiClient;

  ExportApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Export a document as Markdown with HTTP info returned
  ///
  /// 
  Future<Response> exportMarkdownWithHttpInfo(int documentId, int templateId) async {
    Object postBody;

    // verify required params are set
    if(documentId == null) {
     throw ApiException(400, "Missing required param: documentId");
    }
    if(templateId == null) {
     throw ApiException(400, "Missing required param: templateId");
    }

    // create path and map variables
    String path = "/export/markdown".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "documentId", documentId));
      queryParams.addAll(_convertParametersForCollectionFormat("", "templateId", templateId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Export a document as Markdown
  ///
  /// 
  Future<MultipartFile> exportMarkdown(int documentId, int templateId) async {
    Response response = await exportMarkdownWithHttpInfo(documentId, templateId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'MultipartFile') as MultipartFile;
    } else {
      return null;
    }
  }

  /// Export a document as PDF with HTTP info returned
  ///
  /// 
  Future<Response> exportPdfWithHttpInfo(int documentId, int templateId) async {
    Object postBody;

    // verify required params are set
    if(documentId == null) {
     throw ApiException(400, "Missing required param: documentId");
    }
    if(templateId == null) {
     throw ApiException(400, "Missing required param: templateId");
    }

    // create path and map variables
    String path = "/export/pdf".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "documentId", documentId));
      queryParams.addAll(_convertParametersForCollectionFormat("", "templateId", templateId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Export a document as PDF
  ///
  /// 
  Future<MultipartFile> exportPdf(int documentId, int templateId) async {
    Response response = await exportPdfWithHttpInfo(documentId, templateId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'MultipartFile') as MultipartFile;
    } else {
      return null;
    }
  }

  /// Export a document as OpenRQM Data for import with HTTP info returned
  ///
  /// 
  Future<Response> exportRawWithHttpInfo(int documentId) async {
    Object postBody;

    // verify required params are set
    if(documentId == null) {
     throw ApiException(400, "Missing required param: documentId");
    }

    // create path and map variables
    String path = "/export/openrqm".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "documentId", documentId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Export a document as OpenRQM Data for import
  ///
  /// 
  Future<MultipartFile> exportRaw(int documentId) async {
    Response response = await exportRawWithHttpInfo(documentId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'MultipartFile') as MultipartFile;
    } else {
      return null;
    }
  }

  /// Get all Markdown templates with HTTP info returned
  ///
  /// 
  Future<Response> getMarkdownTemplatesWithHttpInfo() async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    String path = "/export/markdown/templates".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get all Markdown templates
  ///
  /// 
  Future<List<RQMTemplate>> getMarkdownTemplates() async {
    Response response = await getMarkdownTemplatesWithHttpInfo();
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<RQMTemplate>') as List).map((item) => item as RQMTemplate).toList();
    } else {
      return null;
    }
  }

  /// Get all PDF templates with HTTP info returned
  ///
  /// 
  Future<Response> getPdfTemplatesWithHttpInfo() async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    String path = "/export/pdf/templates".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get all PDF templates
  ///
  /// 
  Future<List<RQMTemplate>> getPdfTemplates() async {
    Response response = await getPdfTemplatesWithHttpInfo();
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<RQMTemplate>') as List).map((item) => item as RQMTemplate).toList();
    } else {
      return null;
    }
  }

}
