part of openrqm.api;



class LinksApi {
  final ApiClient apiClient;

  LinksApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Delete a link with HTTP info returned
  ///
  /// 
  Future deleteLinkWithHttpInfo(int linkId) async {
    Object postBody;

    // verify required params are set
    if(linkId == null) {
     throw ApiException(400, "Missing required param: linkId");
    }

    // create path and map variables
    String path = "/link".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "linkId", linkId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'DELETE',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Delete a link
  ///
  /// 
  Future deleteLink(int linkId) async {
    Response response = await deleteLinkWithHttpInfo(linkId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Get the link types with HTTP info returned
  ///
  /// 
  Future<Response> getLinkTypesWithHttpInfo() async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    String path = "/linkTypes".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get the link types
  ///
  /// 
  Future<List<RQMLinkType>> getLinkTypes() async {
    Response response = await getLinkTypesWithHttpInfo();
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<RQMLinkType>') as List).map((item) => item as RQMLinkType).toList();
    } else {
      return null;
    }
  }

  /// Link two elements with HTTP info returned
  ///
  /// 
  Future<Response> linkElementWithHttpInfo({ RQMLink link }) async {
    Object postBody = link;

    // verify required params are set

    // create path and map variables
    String path = "/link".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Link two elements
  ///
  /// 
  Future<RQMLink> linkElement({ RQMLink link }) async {
    Response response = await linkElementWithHttpInfo( link: link );
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'RQMLink') as RQMLink;
    } else {
      return null;
    }
  }

}
