part of openrqm.api;



class ThemesApi {
  final ApiClient apiClient;

  ThemesApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Create a new theme with HTTP info returned
  ///
  /// 
  Future createThemeWithHttpInfo(RQMTheme theme) async {
    Object postBody = theme;

    // verify required params are set
    if(theme == null) {
     throw ApiException(400, "Missing required param: theme");
    }

    // create path and map variables
    String path = "/theme".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Create a new theme
  ///
  /// 
  Future createTheme(RQMTheme theme) async {
    Response response = await createThemeWithHttpInfo(theme);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Get all element type colors of a theme with HTTP info returned
  ///
  /// 
  Future<Response> getElementTypeColorsOfThemeWithHttpInfo(int themeId) async {
    Object postBody;

    // verify required params are set
    if(themeId == null) {
     throw ApiException(400, "Missing required param: themeId");
    }

    // create path and map variables
    String path = "/theme/elementTypeColors".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "themeId", themeId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get all element type colors of a theme
  ///
  /// 
  Future<List<RQMElementTypeColor>> getElementTypeColorsOfTheme(int themeId) async {
    Response response = await getElementTypeColorsOfThemeWithHttpInfo(themeId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<RQMElementTypeColor>') as List).map((item) => item as RQMElementTypeColor).toList();
    } else {
      return null;
    }
  }

  /// Get a theme with HTTP info returned
  ///
  /// 
  Future<Response> getThemeWithHttpInfo(int themeId) async {
    Object postBody;

    // verify required params are set
    if(themeId == null) {
     throw ApiException(400, "Missing required param: themeId");
    }

    // create path and map variables
    String path = "/theme".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "themeId", themeId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get a theme
  ///
  /// 
  Future<RQMTheme> getTheme(int themeId) async {
    Response response = await getThemeWithHttpInfo(themeId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'RQMTheme') as RQMTheme;
    } else {
      return null;
    }
  }

  /// Get all themes of a document with HTTP info returned
  ///
  /// 
  Future<Response> getThemesOfDocumentWithHttpInfo(int documentId) async {
    Object postBody;

    // verify required params are set
    if(documentId == null) {
     throw ApiException(400, "Missing required param: documentId");
    }

    // create path and map variables
    String path = "/document/themes".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "documentId", documentId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get all themes of a document
  ///
  /// 
  Future<List<RQMTheme>> getThemesOfDocument(int documentId) async {
    Response response = await getThemesOfDocumentWithHttpInfo(documentId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<RQMTheme>') as List).map((item) => item as RQMTheme).toList();
    } else {
      return null;
    }
  }

  /// Update a theme with HTTP info returned
  ///
  /// 
  Future updateThemeWithHttpInfo(RQMTheme theme) async {
    Object postBody = theme;

    // verify required params are set
    if(theme == null) {
     throw ApiException(400, "Missing required param: theme");
    }

    // create path and map variables
    String path = "/theme".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'PATCH',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Update a theme
  ///
  /// 
  Future updateTheme(RQMTheme theme) async {
    Response response = await updateThemeWithHttpInfo(theme);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

}
