part of openrqm.api;



class WorkspacesApi {
  final ApiClient apiClient;

  WorkspacesApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Add an access group to a workspace with HTTP info returned
  ///
  /// 
  Future addAccessGroupToWorkspaceWithHttpInfo(int workspaceId, { RQMWorkspaceAccessgroup accessGroup }) async {
    Object postBody = accessGroup;

    // verify required params are set
    if(workspaceId == null) {
     throw ApiException(400, "Missing required param: workspaceId");
    }

    // create path and map variables
    String path = "/workspace/accessgroups".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "workspaceId", workspaceId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Add an access group to a workspace
  ///
  /// 
  Future addAccessGroupToWorkspace(int workspaceId, { RQMWorkspaceAccessgroup accessGroup }) async {
    Response response = await addAccessGroupToWorkspaceWithHttpInfo(workspaceId,  accessGroup: accessGroup );
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Add a user to a workspace with HTTP info returned
  ///
  /// 
  Future addUserToWorkspaceWithHttpInfo(int workspaceId, { RQMWorkspaceUser user }) async {
    Object postBody = user;

    // verify required params are set
    if(workspaceId == null) {
     throw ApiException(400, "Missing required param: workspaceId");
    }

    // create path and map variables
    String path = "/workspace/users".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "workspaceId", workspaceId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Add a user to a workspace
  ///
  /// 
  Future addUserToWorkspace(int workspaceId, { RQMWorkspaceUser user }) async {
    Response response = await addUserToWorkspaceWithHttpInfo(workspaceId,  user: user );
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Delete a workspace with HTTP info returned
  ///
  /// 
  Future deleteAccessGroupOfWorkspaceWithHttpInfo(int workspaceId, int accessGroupId) async {
    Object postBody;

    // verify required params are set
    if(workspaceId == null) {
     throw ApiException(400, "Missing required param: workspaceId");
    }
    if(accessGroupId == null) {
     throw ApiException(400, "Missing required param: accessGroupId");
    }

    // create path and map variables
    String path = "/workspace/accessgroups".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "workspaceId", workspaceId));
      queryParams.addAll(_convertParametersForCollectionFormat("", "accessGroupId", accessGroupId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'DELETE',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Delete a workspace
  ///
  /// 
  Future deleteAccessGroupOfWorkspace(int workspaceId, int accessGroupId) async {
    Response response = await deleteAccessGroupOfWorkspaceWithHttpInfo(workspaceId, accessGroupId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Delete a user of a workspace with HTTP info returned
  ///
  /// 
  Future deleteUserOfWorkspaceWithHttpInfo(int workspaceId, int userId) async {
    Object postBody;

    // verify required params are set
    if(workspaceId == null) {
     throw ApiException(400, "Missing required param: workspaceId");
    }
    if(userId == null) {
     throw ApiException(400, "Missing required param: userId");
    }

    // create path and map variables
    String path = "/workspace/users".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "workspaceId", workspaceId));
      queryParams.addAll(_convertParametersForCollectionFormat("", "userId", userId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'DELETE',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Delete a user of a workspace
  ///
  /// 
  Future deleteUserOfWorkspace(int workspaceId, int userId) async {
    Response response = await deleteUserOfWorkspaceWithHttpInfo(workspaceId, userId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Delete a workspace with HTTP info returned
  ///
  /// 
  Future deleteWorkspaceWithHttpInfo(int workspaceId) async {
    Object postBody;

    // verify required params are set
    if(workspaceId == null) {
     throw ApiException(400, "Missing required param: workspaceId");
    }

    // create path and map variables
    String path = "/workspace".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "workspaceId", workspaceId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'DELETE',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Delete a workspace
  ///
  /// 
  Future deleteWorkspace(int workspaceId) async {
    Response response = await deleteWorkspaceWithHttpInfo(workspaceId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Get all access groups of a given workspace with HTTP info returned
  ///
  /// 
  Future<Response> getAccessGroupsOfWorkspaceWithHttpInfo(int workspaceId) async {
    Object postBody;

    // verify required params are set
    if(workspaceId == null) {
     throw ApiException(400, "Missing required param: workspaceId");
    }

    // create path and map variables
    String path = "/workspace/accessgroups".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "workspaceId", workspaceId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get all access groups of a given workspace
  ///
  /// 
  Future<List<RQMWorkspaceAccessgroup>> getAccessGroupsOfWorkspace(int workspaceId) async {
    Response response = await getAccessGroupsOfWorkspaceWithHttpInfo(workspaceId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<RQMWorkspaceAccessgroup>') as List).map((item) => item as RQMWorkspaceAccessgroup).toList();
    } else {
      return null;
    }
  }

  /// Get all users of a given workspace with HTTP info returned
  ///
  /// 
  Future<Response> getUsersOfWorkspaceWithHttpInfo(int workspaceId) async {
    Object postBody;

    // verify required params are set
    if(workspaceId == null) {
     throw ApiException(400, "Missing required param: workspaceId");
    }

    // create path and map variables
    String path = "/workspace/users".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "workspaceId", workspaceId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get all users of a given workspace
  ///
  /// 
  Future<List<RQMWorkspaceUser>> getUsersOfWorkspace(int workspaceId) async {
    Response response = await getUsersOfWorkspaceWithHttpInfo(workspaceId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<RQMWorkspaceUser>') as List).map((item) => item as RQMWorkspaceUser).toList();
    } else {
      return null;
    }
  }

  /// Get a workspace with HTTP info returned
  ///
  /// 
  Future<Response> getWorkspaceWithHttpInfo(int workspaceId) async {
    Object postBody;

    // verify required params are set
    if(workspaceId == null) {
     throw ApiException(400, "Missing required param: workspaceId");
    }

    // create path and map variables
    String path = "/workspace".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "workspaceId", workspaceId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get a workspace
  ///
  /// 
  Future<RQMWorkspace> getWorkspace(int workspaceId) async {
    Response response = await getWorkspaceWithHttpInfo(workspaceId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'RQMWorkspace') as RQMWorkspace;
    } else {
      return null;
    }
  }

  /// Get all workspaces with HTTP info returned
  ///
  /// 
  Future<Response> getWorkspacesWithHttpInfo() async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    String path = "/workspaces".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get all workspaces
  ///
  /// 
  Future<List<RQMWorkspace>> getWorkspaces() async {
    Response response = await getWorkspacesWithHttpInfo();
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<RQMWorkspace>') as List).map((item) => item as RQMWorkspace).toList();
    } else {
      return null;
    }
  }

  /// Update an access group of a workspace with HTTP info returned
  ///
  /// 
  Future patchAccessGroupOfWorkspaceWithHttpInfo(int workspaceId, { RQMWorkspaceAccessgroup accessGroup }) async {
    Object postBody = accessGroup;

    // verify required params are set
    if(workspaceId == null) {
     throw ApiException(400, "Missing required param: workspaceId");
    }

    // create path and map variables
    String path = "/workspace/accessgroups".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "workspaceId", workspaceId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'PATCH',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Update an access group of a workspace
  ///
  /// 
  Future patchAccessGroupOfWorkspace(int workspaceId, { RQMWorkspaceAccessgroup accessGroup }) async {
    Response response = await patchAccessGroupOfWorkspaceWithHttpInfo(workspaceId,  accessGroup: accessGroup );
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Update a user of a workspace with HTTP info returned
  ///
  /// 
  Future patchUserOfWorkspaceWithHttpInfo(int workspaceId, { RQMWorkspaceUser user }) async {
    Object postBody = user;

    // verify required params are set
    if(workspaceId == null) {
     throw ApiException(400, "Missing required param: workspaceId");
    }

    // create path and map variables
    String path = "/workspace/users".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "workspaceId", workspaceId));

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'PATCH',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Update a user of a workspace
  ///
  /// 
  Future patchUserOfWorkspace(int workspaceId, { RQMWorkspaceUser user }) async {
    Response response = await patchUserOfWorkspaceWithHttpInfo(workspaceId,  user: user );
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Update a workspace with HTTP info returned
  ///
  /// 
  Future patchWorkspaceWithHttpInfo(RQMWorkspace workspace) async {
    Object postBody = workspace;

    // verify required params are set
    if(workspace == null) {
     throw ApiException(400, "Missing required param: workspace");
    }

    // create path and map variables
    String path = "/workspace".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'PATCH',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Update a workspace
  ///
  /// 
  Future patchWorkspace(RQMWorkspace workspace) async {
    Response response = await patchWorkspaceWithHttpInfo(workspace);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Add a workspace with HTTP info returned
  ///
  /// 
  Future postWorkspaceWithHttpInfo(RQMWorkspace workspace) async {
    Object postBody = workspace;

    // verify required params are set
    if(workspace == null) {
     throw ApiException(400, "Missing required param: workspace");
    }

    // create path and map variables
    String path = "/workspace".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["APIKeyHeader"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Add a workspace
  ///
  /// 
  Future postWorkspace(RQMWorkspace workspace) async {
    Response response = await postWorkspaceWithHttpInfo(workspace);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

}
